@@ -5,7 +5,7 @@ is.calibrated<-function(design){ !is.null(design$postStrata)}
 
 
 calibrate.survey.design2<-function(design, formula, population,
-                                   stage=NULL,  ...){
+                                   stage=NULL,  lambda=NULL,...){
   
   if (is.null(stage))
     stage<-if (is.list(population)) 1 else 0
@@ -15,21 +15,30 @@ calibrate.survey.design2<-function(design, formula, population,
     mm<-model.matrix(formula, model.frame(formula, design$variables))
     whalf<-sqrt(weights(design))
     sample.total<-colSums(mm*whalf*whalf)
+
+    if (is.null(lambda))
+      sigma2<-rep(1,nrow(mm))
+    else
+      sigma2<-drop(mm%*%lambda)
     
     if (length(sample.total)!=length(population))
       stop("Population and sample totals are not the same length.")
     
     if (any(names(sample.total)!=names(population)))
       warning("Sample and population totals have different names.")
+
+    tqr<-qr(mm*whalf/sqrt(sigma2))
+    if (is.null(lambda) && !all(abs(qr.resid(tqr,sigma2)) <1e-7))
+      stop("Calibration models with constant variance must have an intercept")
     
-    Tmat<-crossprod(mm*whalf)
+    Tmat<-crossprod(mm*whalf/sqrt(sigma2))
     
     tT<-solve(Tmat,population-sample.total)
     
-    g<-drop(1+mm%*%tT)
+    g<-drop(1+mm%*%tT/sigma2)
     design$prob<-design$prob/g
     
-    caldata<- list(qr=qr(mm), w=g*whalf*whalf, stage=0, index=NULL)
+    caldata<- list(qr=tqr, w=g*whalf*sqrt(sigma2), stage=0, index=NULL)
    
   } else {
     ## Calibration within clusters (Sarndal's Case C)
@@ -47,44 +56,59 @@ calibrate.survey.design2<-function(design, formula, population,
 
     mm<-model.matrix(formula, model.frame(formula, design$variables))
 
+    if (is.null(lambda))
+      sigma2<-rep(1,nrow(mm))
+    else
+      sigma2<-drop(mm%*%lambda)
+    
     if(NCOL(mm)!=length(population[[1]]))
         stop("Population and sample totals are not the same length.")
       
     if (any(colnames(mm)!=names(population[[1]])))
       warning("Sample and population totals have different names.")
-
+  
     stageweights<-1/apply(design$allprob[,1:stage,drop=FALSE],1,prod)
     if (any(duplicated(design$cluster[!duplicated(stageweights),stage])))
       stop("Weights at stage", stage, "vary within sampling units")
-    dwhalf<-sqrt(weights(design))
+
     cwhalf<-sqrt(weights(design)/stageweights)
-    
+    dwhalf<-sqrt(weights(design))
+    tqr<-qr(mm)
+    if (is.null(lambda) && !all(abs(qr.resid(tqr,sigma2)) <1e-7))
+      stop("Calibration models with constant variance must have an intercept")
+ 
     for (i in 1:length(clusters)){ 
       cluster<-clusters[[i]]
       these<-which(cluster ==  as.character(design$cluster[,stage]))
       sample.total<-colSums(mm[these,,drop=FALSE]*cwhalf[these]*cwhalf[these])
-      Tmat<-crossprod(mm[these,,drop=FALSE]*cwhalf[these])
+      tqr<-qr(mm[these,,drop=FALSE]*cwhalf[these]/sqrt(sigma2[these]))
+      Tmat<-crossprod(mm[these,,drop=FALSE]*cwhalf[these]/sqrt(sigma2[these]))
       tT<-solve(Tmat,population[[i]]-sample.total)
-      g<-drop(1+mm[these,,drop=FALSE]%*%tT)
+      g<-drop(1+mm[these,,drop=FALSE]%*%tT/sigma2[these])
       design$prob[these]<-design$prob[these]/g
-      caldata$qr[[i]]<-qr(mm[these,,drop=FALSE])
-      caldata$w[[i]]<-g*stageweights[these]*cwhalf[these]^2
+      caldata$qr[[i]]<-tqr
+      caldata$w[[i]]<-g*stageweights[these]*sqrt(sigma2[these])*cwhalf[these]^2
     }
   }  
   class(caldata)<-"greg_calibration"
   
   design$postStrata<-c(design$postStrata, list(caldata))
-  design$call<-sys.call()
+  design$call<-sys.call(-1)
   
   design
 }
 
 
-calibrate.svyrep.design<-function(design, formula, population,compress=NA,...){
+calibrate.svyrep.design<-function(design, formula, population,compress=NA,lambda=NULL,...){
   mf<-model.frame(formula, design$variables)
   mm<-model.matrix(formula, mf)
   whalf<-sqrt(design$pweights)
 
+  if (is.null(lambda))
+    sigma2<-rep(1,nrow(mm))
+  else
+    sigma2<-drop(mm%*%lambda)
+  
   repwt<-as.matrix(design$repweights)
   if (!design$combined.weights)
     repwt<-repwt*design$pweights
@@ -100,14 +124,14 @@ calibrate.svyrep.design<-function(design, formula, population,compress=NA,...){
   
   tT<-solve(Tmat,population-sample.total)
   
-  g<-drop(1+mm%*%tT)
+  g<-drop(1+mm%*%tT/sigma2)
   design$pweights<-design$pweights*g
   
   for(i in 1:NCOL(repwt)){
     whalf<-sqrt(repwt[,i])
-    Tmat<-crossprod(mm*whalf)
+    Tmat<-crossprod(mm*whalf/sqrt(sigma2))
     sample.total<-colSums(mm*whalf*whalf)
-    g<-drop(1+mm%*%solve(Tmat,population-sample.total))
+    g<-drop(1+mm%*%solve(Tmat,population-sample.total)/sigma2)
     repwt[,i]<-repwt[,i]*g
   }
 
@@ -120,7 +144,7 @@ calibrate.svyrep.design<-function(design, formula, population,compress=NA,...){
   }
     
   design$repweights<-repwt
-  design$call<-sys.call()
+  design$call<-sys.call(-1)
 
   design
 }
